Module load

Functions

get_ftag_backup_path
Get the path of the backup ftag file corresponding to path.
get_ftag_path
Get the path of the store file corresponding to path. path can be a filepath, in which case the store file will be it’s sibling, or a directory path, in which case the store file will be it’s child.