Module query

Structs

TagTable
This is similar to a TagTable, but the flags indicating in which file has which tags are stored in a dense 2d array rather than a sparse hash-map of vectors.

Functions

count_files_tags
Returns the number of files and the number of tags.
run_query