Functions
- get_
ftag_ backup_ path - Get the path of the backup ftag file corresponding to
path. - get_
ftag_ path - Get the path of the store file corresponding to
path.pathcan be a filepath, in which case the store file will be it’s sibling, or a directory path, in which case the store file will be it’s child.